# Installation

The library can be installed using pip:

```
pip install qt-material-ui
```

Qt itself isn't included, since this library is using
[qtpy](https://pypi.org/project/QtPy/) to support multiple versions of
Qt. If needed, PySide6 can be installed as well:

```
pip install PySide6
```
